<?php





require_once 'config.php';
require_once GREEN_ZONE_DIR . 'Tests/BaseTest.php';
require_once 'Classes/General/File.php';
require_once 'Classes/Model/Observation.php';
require_once 'Classes/Pulsar/ObservationData2.php';




class TestObservationData2 extends BaseTest
{
  public function TestIt()
  {
    $this->TestCPSR2Data();
    $this->TestDFBData();
  }

  /**
   * Create a File pointing at the CPSR2 test dir
   *
   * Create an Observation object
   * Set some test fields including filename,data_loc
   *
   * Create an ObservationData2 object
   * set the observation
   * Set the data directory
   *
   * Get the original file and check it
   * Get the data file and check it
   * Get the scrunched file and check it
   **/
  public function TestCPSR2Data()
  {
    $cpsr2_path = '/pulsar/archive05/CPSR2/J0437-4715/2006-04-11-05:10:39';
    $data_path = '/pulsar/scratch01/data_archive';
    $expected_data_file = File::ConvertFullPath( $data_path . '/' . '2006-04-11-05:10:39' );
    $expected_scr_file = File::ConvertFullPath( $data_path .'/' . '2006-04-11-05:10:39_T1F128p' );

    $cpsr2_file = File::ConvertFullPath( $cpsr2_path );
    $data_dir = Dir::ConvertPathString( $data_path );
    
    $obs = new Observation();
    $obs->SetFile( $cpsr2_file );
    
    $data = new ObservationData2();
    $data->SetObservationHeader( $obs );
    $data->SetDataDir( $data_dir );
    
    $scr_params = new ScrunchingParameters();
    $scr_params->SetTScrunch( 1 );
    $scr_params->SetFScrunch( 128 );
    $scr_params->SetPScrunch();
    
    $data->SetScrunchingParameters( $scr_params );
    
    $original_file = $data->GetOriginalFile();
    $data_file = $data->GetDataFile();
    $scrunched_file = $data->GetScrunchedFile();
    
    $this->PerformTest( 'Testing GetOriginalFile',
                        ( $original_file->GetFullPath() == $cpsr2_path ),
                          'ObservationData2 returned the wrong path ' . $cspr2_path );
    
    $this->PerformTest( 'Testing GetDataFile',
                         ( $expected_data_file->GetFullPath() == $data_file->GetFullPath() ),
                           'Failed to create data file ' . $expected_data_file->GetFullPath() . ' ' . $data_file->GetFullPath() );
    
    $this->PerformTest( 'Testing GetScrunchedFile',
                        ( $expected_scr_file->GetFullPath() == $scrunched_file->GetFullPath() ),
                          'Failed to create scrunched file ' . $expected_scr_file->GetFullPath() . ' ' . $scrunched_file->GetFullPath() );
  }

  /**
   * Create a File pointing at the DFB test dir
   *
   * Create an Observation object
   * Set some test fields including filename,data_loc
   *
   * Create an ObservationData2 object
   * set the observation
   * Set the data directory
   *
   * Get the original file and check it
   * Get the data file and check it
   * Get the scrunched file and check it
   **/
  public function TestDFBData()
  {
    $src_archive = File::ConvertFullPath( '/pulsar/archive12/DFB/J1019-5749_R/r080208_114145.cf' );
    $data_dir = Dir::ConvertPathString( '/pulsar/scratch01/data_archive' );
    $expected_data_file = File::ConvertFullPath( '/pulsar/scratch01/data_archive/r080208_114145.cf' );
    $expected_scr_file = File::ConvertFullPath( '/pulsar/scratch01/data_archive/r080208_114145_T1F128p.cf' );
    
    $obs = new Observation();
    $obs->SetFile( $src_archive );
    
    $data = new ObservationData2();
    $data->SetObservationHeader( $obs );
    $data->SetDataDir( $data_dir );
    
    $scr_params = new ScrunchingParameters();
    $scr_params->SetTScrunch( 1 );
    $scr_params->SetFScrunch( 128 );
    $scr_params->SetPScrunch();
    
    $data->SetScrunchingParameters( $scr_params );
    
    $original_file = $data->GetOriginalFile();
    $data_file = $data->GetDataFile();
    $scrunched_file = $data->GetScrunchedFile();
    
    $this->PerformTest( 'Testing GetOriginalFile',
                        ( $original_file->GetFullPath() == $src_archive->GetFullPath() ),
                          'ObservationData2 returned the wrong path ' . $original_file->GetFullPath() );
    
    $this->PerformTest( 'Testing GetDataFile',
                        ( $expected_data_file->GetFullPath() == $data_file->GetFullPath() ),
                          'Failed to create data file ' . $expected_data_file->GetFullPath() . ' ' . $data_file->GetFullPath() );
    
    $this->PerformTest( 'Testing GetScrunchedFile',
                        ( $expected_scr_file->GetFullPath() == $scrunched_file->GetFullPath() ),
                          'Failed to create scrunched file ' . $expected_scr_file->GetFullPath() . ' ' . $scrunched_file->GetFullPath() );
  }
};

?>

